summaryrefslogtreecommitdiff
path: root/sw/inc/numrule.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/numrule.hxx')
-rw-r--r--sw/inc/numrule.hxx92
1 files changed, 46 insertions, 46 deletions
diff --git a/sw/inc/numrule.hxx b/sw/inc/numrule.hxx
index 11920c2d6f61..d1125a0f4130 100644
--- a/sw/inc/numrule.hxx
+++ b/sw/inc/numrule.hxx
@@ -81,8 +81,8 @@ public:
SwNumFmt& operator=( const SwNumFmt& );
- BOOL operator==( const SwNumFmt& ) const;
- BOOL operator!=( const SwNumFmt& r ) const { return !(*this == r); }
+ sal_Bool operator==( const SwNumFmt& ) const;
+ sal_Bool operator!=( const SwNumFmt& r ) const { return !(*this == r); }
SwCharFmt* GetCharFmt() const { return (SwCharFmt*)pRegisteredIn; }
void SetCharFmt( SwCharFmt* );
@@ -97,8 +97,8 @@ public:
virtual sal_Int16 GetVertOrient() const;
const SwFmtVertOrient* GetGraphicOrientation() const;
- BOOL IsEnumeration() const; // #i22362#
- BOOL IsItemize() const; // #i29560#
+ sal_Bool IsEnumeration() const; // #i22362#
+ sal_Bool IsItemize() const; // #i29560#
};
class SwPaM;
@@ -119,12 +119,12 @@ private:
#endif
static SwNumFmt* aBaseFmts [ RULE_END ][ MAXLEVEL ];
- static USHORT aDefNumIndents[ MAXLEVEL ];
+ static sal_uInt16 aDefNumIndents[ MAXLEVEL ];
// --> OD 2008-02-11 #newlistlevelattrs#
// default list level properties for position-and-space mode LABEL_ALIGNMENT
static SwNumFmt* aLabelAlignmentBaseFmts [ RULE_END ][ MAXLEVEL ];
// <--
- static USHORT nRefCount;
+ static sal_uInt16 nRefCount;
static char* pDefOutlineName;
SwNumFmt* aFmts[ MAXLEVEL ];
@@ -151,13 +151,13 @@ private:
String sName;
SwNumRuleType eRuleType;
- USHORT nPoolFmtId; // Id-fuer "automatich" erzeugte NumRules
- USHORT nPoolHelpId; // HelpId fuer diese Pool-Vorlage
- BYTE nPoolHlpFileId; // FilePos ans Doc auf die Vorlagen-Hilfen
- BOOL bAutoRuleFlag : 1;
- BOOL bInvalidRuleFlag : 1;
- BOOL bContinusNum : 1; // Fortlaufende Numerierung - ohne Ebenen
- BOOL bAbsSpaces : 1; // die Ebenen repraesentieren absol. Einzuege
+ sal_uInt16 nPoolFmtId; // Id-fuer "automatich" erzeugte NumRules
+ sal_uInt16 nPoolHelpId; // HelpId fuer diese Pool-Vorlage
+ sal_uInt8 nPoolHlpFileId; // FilePos ans Doc auf die Vorlagen-Hilfen
+ sal_Bool bAutoRuleFlag : 1;
+ sal_Bool bInvalidRuleFlag : 1;
+ sal_Bool bContinusNum : 1; // Fortlaufende Numerierung - ohne Ebenen
+ sal_Bool bAbsSpaces : 1; // die Ebenen repraesentieren absol. Einzuege
bool mbCountPhantoms;
// --> OD 2008-02-11 #newlistlevelattrs#
@@ -177,28 +177,28 @@ public:
SwNumRule( const String& rNm,
const SvxNumberFormat::SvxNumPositionAndSpaceMode eDefaultNumberFormatPositionAndSpaceMode,
SwNumRuleType = NUM_RULE,
- BOOL bAutoFlg = TRUE );
+ sal_Bool bAutoFlg = sal_True );
SwNumRule( const SwNumRule& );
~SwNumRule();
SwNumRule& operator=( const SwNumRule& );
- BOOL operator==( const SwNumRule& ) const;
- BOOL operator!=( const SwNumRule& r ) const { return !(*this == r); }
+ sal_Bool operator==( const SwNumRule& ) const;
+ sal_Bool operator!=( const SwNumRule& r ) const { return !(*this == r); }
- const SwNumFmt* GetNumFmt( USHORT i ) const;
- const SwNumFmt& Get( USHORT i ) const;
+ const SwNumFmt* GetNumFmt( sal_uInt16 i ) const;
+ const SwNumFmt& Get( sal_uInt16 i ) const;
- void Set( USHORT i, const SwNumFmt* );
- void Set( USHORT i, const SwNumFmt& );
- String MakeNumString( const SwNodeNum&, BOOL bInclStrings = TRUE,
- BOOL bOnlyArabic = FALSE ) const;
+ void Set( sal_uInt16 i, const SwNumFmt* );
+ void Set( sal_uInt16 i, const SwNumFmt& );
+ String MakeNumString( const SwNodeNum&, sal_Bool bInclStrings = sal_True,
+ sal_Bool bOnlyArabic = sal_False ) const;
// --> OD 2005-10-17 #126238#
// - add optional parameter <_nRestrictToThisLevel> in order to
// restrict returned string to this level.
String MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
- const BOOL bInclStrings = TRUE,
- const BOOL bOnlyArabic = FALSE,
+ const sal_Bool bInclStrings = sal_True,
+ const sal_Bool bOnlyArabic = sal_False,
const unsigned int _nRestrictToThisLevel = MAXLEVEL ) const;
// <--
// --> OD 2007-08-24 #i81002#
@@ -249,12 +249,12 @@ public:
static char* GetOutlineRuleName() { return pDefOutlineName; }
- static USHORT GetNumIndent( BYTE nLvl );
- static USHORT GetBullIndent( BYTE nLvl );
+ static sal_uInt16 GetNumIndent( sal_uInt8 nLvl );
+ static sal_uInt16 GetBullIndent( sal_uInt8 nLvl );
SwNumRuleType GetRuleType() const { return eRuleType; }
void SetRuleType( SwNumRuleType eNew ) { eRuleType = eNew;
- bInvalidRuleFlag = TRUE; }
+ bInvalidRuleFlag = sal_True; }
// eine Art Copy-Constructor, damit die Num-Formate auch an den
// richtigen CharFormaten eines Dokumentes haengen !!
@@ -271,33 +271,33 @@ public:
IDocumentListsAccess& rDocListAccess ); // #i36749#
// <--
- BOOL IsAutoRule() const { return bAutoRuleFlag; }
- void SetAutoRule( BOOL bFlag ) { bAutoRuleFlag = bFlag; }
+ sal_Bool IsAutoRule() const { return bAutoRuleFlag; }
+ void SetAutoRule( sal_Bool bFlag ) { bAutoRuleFlag = bFlag; }
- BOOL IsInvalidRule() const { return bInvalidRuleFlag; }
- void SetInvalidRule( BOOL bFlag );
+ sal_Bool IsInvalidRule() const { return bInvalidRuleFlag; }
+ void SetInvalidRule( sal_Bool bFlag );
- BOOL IsContinusNum() const { return bContinusNum; }
- void SetContinusNum( BOOL bFlag ) { bContinusNum = bFlag; }
+ sal_Bool IsContinusNum() const { return bContinusNum; }
+ void SetContinusNum( sal_Bool bFlag ) { bContinusNum = bFlag; }
- BOOL IsAbsSpaces() const { return bAbsSpaces; }
- void SetAbsSpaces( BOOL bFlag ) { bAbsSpaces = bFlag; }
+ sal_Bool IsAbsSpaces() const { return bAbsSpaces; }
+ void SetAbsSpaces( sal_Bool bFlag ) { bAbsSpaces = bFlag; }
// #115901#
- BOOL IsOutlineRule() const { return eRuleType == OUTLINE_RULE; }
+ sal_Bool IsOutlineRule() const { return eRuleType == OUTLINE_RULE; }
bool IsCountPhantoms() const;
void SetCountPhantoms(bool bCountPhantoms);
// erfragen und setzen der Poolvorlagen-Id's
- USHORT GetPoolFmtId() const { return nPoolFmtId; }
- void SetPoolFmtId( USHORT nId ) { nPoolFmtId = nId; }
+ sal_uInt16 GetPoolFmtId() const { return nPoolFmtId; }
+ void SetPoolFmtId( sal_uInt16 nId ) { nPoolFmtId = nId; }
// erfragen und setzen der Hilfe-Id's fuer die Document-Vorlagen
- USHORT GetPoolHelpId() const { return nPoolHelpId; }
- void SetPoolHelpId( USHORT nId ) { nPoolHelpId = nId; }
- BYTE GetPoolHlpFileId() const { return nPoolHlpFileId; }
- void SetPoolHlpFileId( BYTE nId ) { nPoolHlpFileId = nId; }
+ sal_uInt16 GetPoolHelpId() const { return nPoolHelpId; }
+ void SetPoolHelpId( sal_uInt16 nId ) { nPoolHelpId = nId; }
+ sal_uInt8 GetPoolHlpFileId() const { return nPoolHlpFileId; }
+ void SetPoolHlpFileId( sal_uInt8 nId ) { nPoolHlpFileId = nId; }
void SetSvxRule(const SvxNumRule&, SwDoc* pDoc);
SvxNumRule MakeSvxNumRule() const;
@@ -306,13 +306,13 @@ public:
// --> OD 2008-06-09 #i90078#
// refactoring: provide certain method for certain purpose
// void Indent(short aAmount, int nLevel = -1,
// int nReferenceLevel = -1, BOOL bRelative = TRUE,
// BOOL bFirstLine = TRUE, BOOL bCheckGtZero = TRUE);
// change indent of all list levels by given difference
void ChangeIndent( const short nDiff );
// set indent of certain list level to given value
void SetIndent( const short nNewIndent,
- const USHORT nListLevel );
+ const sal_uInt16 nListLevel );
// set indent of first list level to given value and change other list level's
// indents accordingly
void SetIndentOfFirstListLevelAndChangeOthers( const short nNewIndent );
@@ -350,7 +350,7 @@ namespace numfunc
@author OD
*/
- sal_Unicode GetBulletChar( BYTE nLevel );
+ sal_Unicode GetBulletChar( sal_uInt8 nLevel );
/** configuration, if at first position of the first list item the <TAB>-key
increased the indent of the complete list or only demotes this list item.
@@ -306,13 +306,13 @@ public:
// refactoring: provide certain method for certain purpose
// void Indent(short aAmount, int nLevel = -1,
-// int nReferenceLevel = -1, BOOL bRelative = TRUE,
-// BOOL bFirstLine = TRUE, BOOL bCheckGtZero = TRUE);
+// int nReferenceLevel = -1, sal_Bool bRelative = sal_True,
+// sal_Bool bFirstLine = sal_True, sal_Bool bCheckGtZero = sal_True);
// change indent of all list levels by given difference
void ChangeIndent( const short nDiff );